import { first, last, sortBy } from "lodash-es";
import { rpcProviderForChain } from "./internal/rpcproviders.js";
import { BigNumber } from "@ethersproject/bignumber";
import { formatUnits } from "@ethersproject/units";
import { chainSupportsEIP1559 } from "./common/chainid.js";
/**
 * Returns the minimum, average, and maximum gas prices from the most recently mined block
 * on a given Chain, as well as the result of eth_getGasPrice.
 * @param chainId
 */
export function fetchChainGasPrices(chainId) {
    var supports1559 = chainSupportsEIP1559(chainId), provider = rpcProviderForChain(chainId), lastPriceProm = provider.getGasPrice();
    return provider.getBlockWithTransactions('latest')
        .then(function (_a) {
        var transactions = _a.transactions;
        return lastPriceProm.then(function (lastPrice) {
            var gasPrices = extractGasPrices(transactions, supports1559);
            var sum = BigNumber.from(0);
            gasPrices.forEach(function (n) { return sum = sum.add(n); });
            return {
                min: first(gasPrices),
                avg: sum.div(gasPrices.length),
                max: last(gasPrices),
                last: lastPrice,
            };
        });
    });
}
function extractGasPrices(txns, supports1559) {
    var gasPrices = txns
        .map(function (txn) { return supports1559 ? txn.maxFeePerGas : txn.gasPrice; })
        .filter(function (val) { return typeof val !== 'undefined' && val !== null && !val.isZero(); });
    return sortBy(gasPrices, [gweiSortFn]);
}
function gweiSortFn(n) {
    return gweiToFloat(toGwei(n));
}
function toGwei(n) {
    return formatUnits(n, "gwei");
}
function gweiToFloat(gwei) {
    return parseFloat(gwei);
}
